changeset 36806:6eaf3f2390b4

(features): Add `md5' and `overlay' to the list.
author Gerd Moellmann <gerd@gnu.org>
date Wed, 14 Mar 2001 15:46:58 +0000
parents a7747c7ba014
children 2c739584e2a6
files lisp/bindings.el
diffstat 1 files changed, 3 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/bindings.el	Wed Mar 14 14:40:54 2001 +0000
+++ b/lisp/bindings.el	Wed Mar 14 15:46:58 2001 +0000
@@ -490,8 +490,10 @@
 
 (make-variable-buffer-local 'indent-tabs-mode)
 
 ;; We have base64 functions built in now.
 (add-to-list 'features 'base64)
+(add-to-list 'features 'md5)
+(add-to-list 'features 'overlay)
 
 (define-key esc-map "\t" 'complete-symbol)
@@ -490,8 +490,10 @@
 (make-variable-buffer-local 'indent-tabs-mode)
 
-;; We have base64 functions built in now.
+;; We have base64 and md5 functions built in now.
 (add-to-list 'features 'base64)